NuRadioReco\.modules package
============================

Subpackages
-----------

.. toctree::

    NuRadioReco.modules.ARA
    NuRadioReco.modules.ARIANNA
    NuRadioReco.modules.io
    NuRadioReco.modules.phasedarray
    NuRadioReco.modules.trigger

Submodules
----------

NuRadioReco\.modules\.channelBandPassFilter module
--------------------------------------------------

.. automodule:: NuRadioReco.modules.channelBandPassFilter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.channelGenericNoiseAdder module
-----------------------------------------------------

.. automodule:: NuRadioReco.modules.channelGenericNoiseAdder
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.channelLengthAdjuster module
--------------------------------------------------

.. automodule:: NuRadioReco.modules.channelLengthAdjuster
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.channelResampler module
---------------------------------------------

.. automodule:: NuRadioReco.modules.channelResampler
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.channelSignalReconstructor module
-------------------------------------------------------

.. automodule:: NuRadioReco.modules.channelSignalReconstructor
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.channelStopFilter module
----------------------------------------------

.. automodule:: NuRadioReco.modules.channelStopFilter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.channelTemplateCorrelation module
-------------------------------------------------------

.. automodule:: NuRadioReco.modules.channelTemplateCorrelation
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.channelTimeWindow module
----------------------------------------------

.. automodule:: NuRadioReco.modules.channelTimeWindow
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.correlationDirectionFitter module
-------------------------------------------------------

.. automodule:: NuRadioReco.modules.correlationDirectionFitter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.cosmicRayEnergyReconstructor module
---------------------------------------------------------

.. automodule:: NuRadioReco.modules.cosmicRayEnergyReconstructor
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.efieldAirToIcePropagator module
-----------------------------------------------------

.. automodule:: NuRadioReco.modules.efieldAirToIcePropagator
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.efieldGenericNoiseAdder module
----------------------------------------------------

.. automodule:: NuRadioReco.modules.efieldGenericNoiseAdder
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.efieldTimeDirectionFitter module
------------------------------------------------------

.. automodule:: NuRadioReco.modules.efieldTimeDirectionFitter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.efieldToVoltageConverter module
-----------------------------------------------------

.. automodule:: NuRadioReco.modules.efieldToVoltageConverter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.electricFieldBandPassFilter module
--------------------------------------------------------

.. automodule:: NuRadioReco.modules.electricFieldBandPassFilter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.electricFieldResampler module
---------------------------------------------------

.. automodule:: NuRadioReco.modules.electricFieldResampler
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.electricFieldSignalReconstructor module
-------------------------------------------------------------

.. automodule:: NuRadioReco.modules.electricFieldSignalReconstructor
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.eventTypeIdentifier module
------------------------------------------------

.. automodule:: NuRadioReco.modules.eventTypeIdentifier
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.templateDirectionFitter module
----------------------------------------------------

.. automodule:: NuRadioReco.modules.templateDirectionFitter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.triggerTimeAdjuster module
------------------------------------------------

.. automodule:: NuRadioReco.modules.triggerTimeAdjuster
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.voltageToAnalyticEfieldConverter module
-------------------------------------------------------------

.. automodule:: NuRadioReco.modules.voltageToAnalyticEfieldConverter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.voltageToEfieldConverter module
-----------------------------------------------------

.. automodule:: NuRadioReco.modules.voltageToEfieldConverter
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.voltageToEfieldConverterPerChannel module
---------------------------------------------------------------

.. automodule:: NuRadioReco.modules.voltageToEfieldConverterPerChannel
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: NuRadioReco.modules
    :members:
    :undoc-members:
    :show-inheritance:
